@@ -25,7 +25,10 @@ def parse_objects(f):
                 and inspect.isclass(this_class)
                 and issubclass(this_class, BaseModel)
             ):
-                kwargs[var_name] = this_class.parse_obj(var_val)
+                if var_val is not None:
+                    kwargs[var_name] = this_class.parse_obj(var_val)
+                else:
+                    kwargs[var_name] = None
 
         if g.settings.print_level > 1:
             print("PARSE OBJS", "args", args, "kwargs", kwargs)
