@@ -21,6 +21,7 @@ from magicapi.RouteClasses import MagicCallLogger
 import redis
 
 R = None
+LAST_SEEN_KEY = "last_seen"
 if g.settings.use_doorman_redis:
     R = redis.Redis(
         host=g.settings.doorman_redis_endpoint,
@@ -130,7 +131,8 @@ def get_current_user_from_token(token: str):
             f"Current User: {current_user.uid}, name: {current_user.display_name}, phone_number: {current_user.phone_number}"
         )
         if R:
-            R.set(current_user.uid, int(time.time()))
+            R.zadd(LAST_SEEN_KEY, int(time.time()))
+            # R.set(current_user.uid, int(time.time()))
         return current_user
     except firebase_admin._token_gen.ExpiredIdTokenError as e:
         print("DOORMAN ERROR", e)
@@ -163,7 +165,8 @@ from datetime import datetime
 
 
 def last_seen_from_uid(uid: str) -> Optional[datetime]:
-    timestamp_str = R.get(uid)
+    timestamp_str = R.zscore(LAST_SEEN_KEY, uid)
+    # timestamp_str = R.get(uid)
     if not timestamp_str:
         return None
     return datetime.fromtimestamp(int(timestamp_str))
